aboutsummaryrefslogtreecommitdiff
path: root/gcc/diagnostic-client-data-hooks.h
diff options
context:
space:
mode:
Diffstat (limited to 'gcc/diagnostic-client-data-hooks.h')
-rw-r--r--gcc/diagnostic-client-data-hooks.h11
1 files changed, 9 insertions, 2 deletions
diff --git a/gcc/diagnostic-client-data-hooks.h b/gcc/diagnostic-client-data-hooks.h
index 0057b80..9909172 100644
--- a/gcc/diagnostic-client-data-hooks.h
+++ b/gcc/diagnostic-client-data-hooks.h
@@ -21,6 +21,8 @@ along with GCC; see the file COPYING3. If not see
#ifndef GCC_DIAGNOSTIC_CLIENT_DATA_HOOKS_H
#define GCC_DIAGNOSTIC_CLIENT_DATA_HOOKS_H
+#include "logical-location.h"
+
class sarif_object;
class client_version_info;
@@ -35,8 +37,13 @@ class diagnostic_client_data_hooks
/* Get version info for this client, or NULL. */
virtual const client_version_info *get_any_version_info () const = 0;
- /* Get the current logical_location for this client, or NULL. */
- virtual const logical_location *get_current_logical_location () const = 0;
+ /* Get the current logical_location_manager for this client, or NULL. */
+ virtual const logical_location_manager *get_logical_location_manager () const = 0;
+
+ /* Get the current logical_location, or null.
+ If this returns a non-null logical_location, then
+ get_logical_location_manager must return non-NULL. */
+ virtual logical_location get_current_logical_location () const = 0;
/* Get a sourceLanguage value for FILENAME, or return NULL.
See SARIF v2.1.0 Appendix J for suggested values. */